==> scanbot_sdk-2.9.0.tar.gz: ios/Classes/Extensions/SDK/NFC/SBSDKUINFCPassportReaderUIConfiguration.swift <==
//
//  SBSDKUINFCPassportReaderUIConfiguration.swift
//  scanbot_sdk
//
//  Created by Yevgeniy Knizhnik on 08.04.21.
//

import Foundation
import ScanbotSDK

extension SBSDKUINFCPassportReaderUIConfiguration {
    convenience init(from dictionary: [String: Any]) {
        self.init()
        if let hex = dictionary["topBarButtonsColor"] as? String {
            self.topBarButtonsColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["topBarBackgroundColor"] as? String {
            self.topBarBackgroundColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["cameraOverlayColor"] as? String {
            self.cameraOverlayColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["finderLineColor"] as? String {
            self.finderLineColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["finderTextHintColor"] as? String {
            self.finderTextHintColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["topBarButtonsInactiveColor"] as? String {
            self.topBarButtonsInactiveColor = UIColor(hexString: hex)
        }
        
        if let cancelButtonHidden = dictionary["cancelButtonHidden"] as? Bool {
            self.isCancelButtonHidden = cancelButtonHidden
        }
        
        if let finderLineWidth = dictionary["finderLineWidth"] as? CGFloat {
            self.finderLineWidth = finderLineWidth
        }
        
        if let hex = dictionary["progressBarColor"] as? String {
            self.progressBarColor = UIColor(hexString: hex)
        }
        
        if let string = dictionary["orientationLockMode"] as? String {
            let allowedInterfaceOrientations = UIInterfaceOrientationMask(from: string)
            self.allowedInterfaceOrientations = allowedInterfaceOrientations
        }
    }
}

==> scanbot_sdk-2.10.0.tar.gz: ios/Classes/Extensions/SDK/NFC/SBSDKUINFCPassportReaderUIConfiguration.swift <==
//
//  SBSDKUINFCPassportReaderUIConfiguration.swift
//  scanbot_sdk
//
//  Created by Yevgeniy Knizhnik on 08.04.21.
//

import Foundation
import ScanbotSDK

extension SBSDKUINFCPassportReaderUIConfiguration {
    convenience init(from dictionary: [String: Any]) {
        self.init()
        if let hex = dictionary["topBarButtonsColor"] as? String {
            self.topBarButtonsColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["topBarBackgroundColor"] as? String {
            self.topBarBackgroundColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["cameraOverlayColor"] as? String {
            self.cameraOverlayColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["finderLineColor"] as? String {
            self.finderLineColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["finderTextHintColor"] as? String {
            self.finderTextHintColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["topBarButtonsInactiveColor"] as? String {
            self.topBarButtonsInactiveColor = UIColor(hexString: hex)
        }
        
        if let cancelButtonHidden = dictionary["cancelButtonHidden"] as? Bool {
            self.isCancelButtonHidden = cancelButtonHidden
        }
        
        if let finderLineWidth = dictionary["finderLineWidth"] as? CGFloat {
            self.finderLineWidth = finderLineWidth
        }
        
        if let hex = dictionary["progressBarColor"] as? String {
            self.progressBarColor = UIColor(hexString: hex)
        }
        
        if let string = dictionary["orientationLockMode"] as? String {
            let orientationLockMode = SBSDKOrientationLock(from: string)
            self.orientationLockMode = orientationLockMode
        }
    }
}
